@@ -1,3 +1,20 @@
+#  File R/install.statnet.R
+#  Part of the "statnet" package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+# Copyright 2003 Mark S. Handcock, University of Washington
+#                David R. Hunter, Penn State University
+#                Carter T. Butts, University of California - Irvine
+#                Martina Morris, University of Washington
+# Copyright 2007 statnet Development Team
+#
+# We have invested a lot of time and effort in creating 'statnet',
+# for use by other researchers. We require that the attributions
+# are retained with each function.
+######################################################################
 "install.statnet" <- function(object, ..., 
             contriburl = "http://statnetproject.org",
             repos = getOption("repos"), type = getOption("pkgType"))
@@ -13,27 +30,34 @@
      contriburl <- "http://csde.washington.edu/statnet"
   }
   cat(paste("Collecting information necessary for the install...\n",sep=""))
-  cran.Base <- c("network", "coda", "statnet","ergm")
+  cran.Base <- c("network", "latentnet", "sna", "statnet", "ergm", "degreenet")
   csde.Base <- c()
-  cran.Recommended <- c("sna", "latentnet")
+  cran.Recommended <- c("coda")
   csde.Recommended <- c()
 # cran.Optional <- c("netdata")
-  cran.Optional <- c("degreenet","networksis")
+  cran.Optional <- c("networksis")
   csde.Optional <- c("netperm","rSoNIA")
-  cran.Base.latentnet <- c("abind", "tools", "mclust", "snowFT",
-                           "akima",  "shapes", "KernSmooth")
+  cran.Base.latentnet <- c("abind", "shapes")
 #
   if(missing(object)){
     object <- c(cran.Base, csde.Base, cran.Recommended,
                 csde.Recommended, cran.Optional, csde.Optional)
   }
-  inuse <- match(paste("package:","statnet",sep=""), search())
-  if(!inherits(try(detach(pos=inuse),silent=TRUE), "try-error")){
-    cat(paste("Detaching package '", "statnet","'.\n",sep=""))
-  }
 #
 # local install functions
 #
+  really.detach <- function(package){
+   inuse <- match(paste("package:",pkg,sep=""), search())
+   if(!is.na(inuse) && !inherits(try(detach(pos=inuse, unload=TRUE),silent=TRUE), "try-error")){
+     cat(paste("Detaching package '", pkg,"'.\n",sep=""))
+     inuse <-  grep(paste("/",package,"$",sep=""),searchpaths())
+     if(length(inuse)>0){
+      inuse <- searchpaths()[inuse]
+      library.dynam.unload(paste(package,".so",sep=""),inuse)
+     }
+   }
+  invisible()
+  }
   statnet.install <- function(object, csde, contriburl=cran.contriburl,
                               ask=FALSE, type="recommended",
                               update.pkgs=update.cran.pkgs){
@@ -45,7 +69,7 @@
        cat(paste("Attempting to update package '", pkg,"'.\n",sep=""))
        inuse <- match(paste("package:",pkg,sep=""), search())
        if(!is.na(inuse)){
-         if(!inherits(try(detach(pos=inuse),silent=TRUE), "try-error")){
+         if(!inherits(try(detach(pos=inuse, unload=TRUE),silent=TRUE), "try-error")){
            cat(paste("Detaching package '", pkg,"'.\n",sep=""))}
        }
        if(ask){
@@ -68,6 +92,8 @@
     }
   invisible()
   }
+# Detach the packages to avoid conflicts
+  for(pkg in object){ really.detach(pkg) }
 # CSDE
   new.csde.pkgs <- new.packages(lib.loc=.libPaths()[1],contriburl=contriburl)
   old.csde.pkgs <- old.packages(lib.loc=.libPaths()[1],contriburl=contriburl)[,1]
